DirectoryRecordHeader

Struct DirectoryRecordHeader 

#[repr(C)]
pub struct DirectoryRecordHeader { pub len: u8, pub extended_attr_record: u8, pub extent: U32LsbMsb, pub data_len: U32LsbMsb, pub date_time: DirDateTime, pub flags: u8, pub file_unit_size: u8, pub interleave_gap_size: u8, pub volume_sequence_number: U16LsbMsb, pub file_identifier_len: u8, }
Available on crate feature sync only.
The header of a directory record, because the identifier is variable length (ECMA-119 9.1 fixed fields).

@hadris-spec ECMA-119:9.1 @hadris-compliance partial @hadris-note Fixed fields round-trip, but all identifier, flag, and semantic constraints are not yet validated. @hadris-tests directory::tests::directory_record_parse_roundtrip @hadris-fuzz iso_read

Fields

len: u8

The len field.

extended_attr_record: u8

The extended_attr_record field.

extent: U32LsbMsb

The LBA of the record

data_len: U32LsbMsb

The length of the data in bytes

date_time: DirDateTime

The date_time field.

flags: u8

The flags field.

file_unit_size: u8

The file_unit_size field.

interleave_gap_size: u8

The interleave_gap_size field.

volume_sequence_number: U16LsbMsb

The volume_sequence_number field.

file_identifier_len: u8

The file_identifier_len field.

Implementations

Source

impl DirectoryRecordHeader

pub fn from_bytes(bytes: &[u8]) -> &Self

Performs the from_bytes operation.

pub fn to_bytes(&self) -> &[u8]

Performs the to_bytes operation.

pub fn is_directory(&self) -> bool

Performs the is_directory operation.