PrimaryVolumeDescriptor

Struct PrimaryVolumeDescriptor 

#[repr(C)]
pub struct PrimaryVolumeDescriptor {
Show 31 fields pub header: VolumeDescriptorHeader, pub unused0: u8, pub system_identifier: IsoStrA<32>, pub volume_identifier: IsoStrD<32>, pub unused1: [u8; 8], pub volume_space_size: U32LsbMsb, pub unused2: [u8; 32], pub volume_set_size: U16LsbMsb, pub volume_sequence_number: U16LsbMsb, pub logical_block_size: U16LsbMsb, pub path_table_size: U32LsbMsb, pub type_l_path_table: U32<LittleEndian>, pub opt_type_l_path_table: U32<LittleEndian>, pub type_m_path_table: U32<BigEndian>, pub opt_type_m_path_table: U32<BigEndian>, pub dir_record: RootDirectoryEntry, pub volume_set_identifier: IsoStrD<128>, pub publisher_identifier: IsoStrA<128>, pub preparer_identifier: IsoStrA<128>, pub application_identifier: IsoStrA<128>, pub copyright_file_identifier: IsoStrD<37>, pub abstract_file_identifier: IsoStrD<37>, pub bibliographic_file_identifier: IsoStrD<37>, pub creation_date: DecDateTime, pub modification_date: DecDateTime, pub expiration_date: DecDateTime, pub effective_date: DecDateTime, pub file_structure_version: u8, pub unused3: u8, pub app_data: [u8; 512], pub reserved: [u8; 653],
}
Available on crate feature sync only.
Primary Volume Descriptor (ECMA-119 8.4)

@hadris-spec ECMA-119:8.4 @hadris-compliance partial @hadris-note Core fields are modeled, but reserved fields, character sets, redundant endian values, and semantic constraints are not all validated. @hadris-tests comprehensive_iso::test_pvd_standard_identifier @hadris-fuzz iso_read

Fields

header: VolumeDescriptorHeader

The header field.

unused0: u8

The unused0 field.

system_identifier: IsoStrA<32>

The system_identifier field.

volume_identifier: IsoStrD<32>

The volume_identifier field.

unused1: [u8; 8]

The unused1 field.

volume_space_size: U32LsbMsb

The volume_space_size field.

unused2: [u8; 32]

The unused2 field.

volume_set_size: U16LsbMsb

The volume_set_size field.

volume_sequence_number: U16LsbMsb

The volume_sequence_number field.

logical_block_size: U16LsbMsb

The logical_block_size field.

path_table_size: U32LsbMsb

The path_table_size field.

type_l_path_table: U32<LittleEndian>

The type_l_path_table field.

opt_type_l_path_table: U32<LittleEndian>

The opt_type_l_path_table field.

type_m_path_table: U32<BigEndian>

The type_m_path_table field.

opt_type_m_path_table: U32<BigEndian>

The opt_type_m_path_table field.

dir_record: RootDirectoryEntry

The dir_record field.

volume_set_identifier: IsoStrD<128>

The volume_set_identifier field.

publisher_identifier: IsoStrA<128>

The publisher_identifier field.

preparer_identifier: IsoStrA<128>

The preparer_identifier field.

application_identifier: IsoStrA<128>

The application_identifier field.

copyright_file_identifier: IsoStrD<37>

The copyright_file_identifier field.

abstract_file_identifier: IsoStrD<37>

The abstract_file_identifier field.

bibliographic_file_identifier: IsoStrD<37>

The bibliographic_file_identifier field.

creation_date: DecDateTime

The creation_date field.

modification_date: DecDateTime

The modification_date field.

expiration_date: DecDateTime

The expiration_date field.

effective_date: DecDateTime

The effective_date field.

file_structure_version: u8

The file_structure_version field.

unused3: u8

The unused3 field.

app_data: [u8; 512]

The app_data field.

reserved: [u8; 653]

The reserved field.

Implementations

Source

impl PrimaryVolumeDescriptor

pub fn new(name: &str, sectors: u32) -> Self

Performs the new operation.